@@ -6,4 +6,4 @@
 @ GitHub : https://github.com/ZeroSeeker
 @ Gitee : https://gitee.com/ZeroSeeker
 """
-from . import datahub
+from .fastaliyun import *
